@@ -52,39 +52,39 @@ def cache_to_django(
                     f'{datetime.datetime.now()} - '
                     f'Written {completed} {django_model} instances from cache to django')
 
-        if cache_conf['delete']:
-
-            async def check_if_need_to_delete_django_instance(redis_instances_django_ids, django_instance):
-                if django_instance.id not in redis_instances_django_ids:
-                    await django_sync_to_async_delete(django_instance)
-
-            all_redis_instances = redis_root.get(django_model)
-            redis_instances_django_ids = []
-            for redis_instance in all_redis_instances:
-                if 'django_id' in redis_instance.keys():
-                    django_id = redis_instance['django_id']
-                    if django_id not in ['null', None]:
-                        redis_instances_django_ids.append(django_id)
-
-            all_django_instances = await django_sync_to_async_list(django_model.objects.all)
-            async_tasks = []
-            completed = 0
-            to_complete = len(all_django_instances)
-            for django_instance in all_django_instances:
-                async_tasks.append(
-                    check_if_need_to_delete_django_instance(
-                        redis_instances_django_ids,
-                        django_instance,
-                    )
-                )
-                completed += 1
-                if len(async_tasks) == async_chunk_size or completed == to_complete:
-                    await asyncio.gather(*async_tasks)
-                    async_tasks = []
-                    print(f'{datetime.datetime.now()} - '
-                          f'Deleted {django_model} instances from django')
-
-            await asyncio.gather(*async_tasks)
+        # if cache_conf['delete']:
+        #
+        #     async def check_if_need_to_delete_django_instance(redis_instances_django_ids, django_instance):
+        #         if django_instance.id not in redis_instances_django_ids:
+        #             await django_sync_to_async_delete(django_instance)
+        #
+        #     all_redis_instances = redis_root.get(django_model)
+        #     redis_instances_django_ids = []
+        #     for redis_instance in all_redis_instances:
+        #         if 'django_id' in redis_instance.keys():
+        #             django_id = redis_instance['django_id']
+        #             if django_id not in ['null', None]:
+        #                 redis_instances_django_ids.append(django_id)
+        #
+        #     all_django_instances = await django_sync_to_async_list(django_model.objects.all)
+        #     async_tasks = []
+        #     completed = 0
+        #     to_complete = len(all_django_instances)
+        #     for django_instance in all_django_instances:
+        #         async_tasks.append(
+        #             check_if_need_to_delete_django_instance(
+        #                 redis_instances_django_ids,
+        #                 django_instance,
+        #             )
+        #         )
+        #         completed += 1
+        #         if len(async_tasks) == async_chunk_size or completed == to_complete:
+        #             await asyncio.gather(*async_tasks)
+        #             async_tasks = []
+        #             print(f'{datetime.datetime.now()} - '
+        #                   f'Deleted {django_model} instances from django')
+        #
+        #     await asyncio.gather(*async_tasks)
 
     loop = asyncio.get_event_loop()
     loop.run_until_complete(run_cache_to_django(
@@ -137,22 +137,27 @@ def sync_to_async_update_or_create_django_instance_from_redis_instance(
 ):
     need_to_create = True
     if django_id not in ['null', None]:
-        print(django_id)
-        print(django_model.objects.filter(id=django_id))
         if django_model.objects.filter(id=django_id):
             need_to_create = False
+    print()
     print(need_to_create)
     django_instance = None
 
     if need_to_create:
         if cache_conf['write_to_django']:
+            redis_instance_id = int(redis_instance['id'])
+            redis_instances = redis_root.get(django_model, id=redis_instance_id)
+            redis_root.delete(django_model, redis_instances)
+            redis_instances = redis_root.get(django_model, id=redis_instance_id)
+            print('MUST BE 0: ', len(list(redis_instances)))
             django_instance = django_model.objects.create(**django_params)
             update_django_many_to_many(
                 django_model,
                 django_instance.id,
-                django_many_to_many_params
+                django_many_to_many_params,
             )
-            redis_root.delete(django_model, redis_instance)
+            redis_instances = redis_root.get(django_model, django_id=int(django_instance.id))
+            print('MUST BE 1: ', len(list(redis_instances)))
             print('cache - created and deleted', django_model, django_instance.id, redis_instance['django_id'])
         else:
             print(f'\n'
@@ -224,7 +229,6 @@ async def async_redis_dict_to_django_params(
                 foreign_key_model = django_field_data['remote_field_model']
                 redis_foreign_key_instance = redis_dict[django_field_name]
                 if redis_foreign_key_instance not in ['null', None]:
-                    print('cache - creating new instance foreign', django_field, redis_foreign_key_instance)
                     django_foreign_key_instance = await update_or_create_django_instance_from_redis_instance(
                         redis_root,
                         redis_foreign_key_instance,
@@ -239,7 +243,6 @@ async def async_redis_dict_to_django_params(
                 django_many_to_many_instances = []
                 redis_many_to_many_instances = redis_dict[django_field_data['name']]
                 if redis_many_to_many_instances not in ['null', None] and redis_many_to_many_instances:
-                    print('cache - creating new instance m2m', django_field, django_model)
                     for redis_many_to_many_instance in redis_many_to_many_instances:
                         django_many_to_many_instance = await update_or_create_django_instance_from_redis_instance(
                             redis_root,
