@@ -23,30 +23,37 @@ class RedisQuerySet(django_models.query.QuerySet):
         id = create_result.id
         existing_fields = {}
         redis_root = get_redis_root()
-        for field in create_result.__class__._meta.get_fields():
-            try:
-                field_name = field.name
-                if field_name in ['id', 'pk']:
-                    field_name = 'django_id'
-                existing_fields[field_name] = django_instance_field_to_redis_value(
-                    redis_root,
-                    create_result,
-                    field,
-                    redis_root.get_cache_conf(self.__class__)
-                )
-            except:
-                pass
-        redis_root.create(self.model, **existing_fields)
+        existing_redis_instances = redis_root.get(self.model, create_result.id)
+        if not existing_redis_instances:
+            for field in create_result.__class__._meta.get_fields():
+                try:
+                    field_name = field.name
+                    if field_name in ['id', 'pk']:
+                        field_name = 'django_id'
+                    existing_fields[field_name] = django_instance_field_to_redis_value(
+                        redis_root,
+                        create_result,
+                        field,
+                        redis_root.get_cache_conf(self.__class__)
+                    )
+                except:
+                    pass
+            redis_root.create(self.model, **existing_fields)
         return create_result
 
     def delete(self):
+        list_self = list(self.copy())
         concrete_model = self.model._meta.concrete_model
         delete_result = super().delete()
         redis_root = get_redis_root()
-        django_instance_ids_to_delete = [int(django_instance.id) for django_instance in self]
+        django_instance_ids_to_delete = [int(django_instance.id) for django_instance in list_self]
+        print(django_instance_ids_to_delete)
         data_to_delete = redis_root.get(self.model, django_id__in=django_instance_ids_to_delete)
+        print('data to delete: ', len(data_to_delete))
         redis_root.delete(self.model, data_to_delete)
-        return self
+        data_to_delete = redis_root.get(self.model, django_id__in=django_instance_ids_to_delete)
+        print('after delete: ', len(data_to_delete))
+        return list_self
 
 class RedisUserObjectsManager(UserManager):
     def get_queryset(self):
@@ -205,9 +212,13 @@ class DjangoRedisModel(django_models.Model):
         delete_result = super().delete(*args, **kwargs)
         redis_root = get_redis_root()
         redis_instance_qs = redis_root.get(self.__class__, django_id=django_id)
+        print('model pre delete: ', len(redis_instance_qs))
         if redis_instance_qs:
             print(self.__class__)
             redis_root.delete(self.__class__, redis_instance_qs)
+            redis_instance_qs = redis_root.get(self.__class__, django_id=django_id)
+            print('model post delete: ', len(redis_instance_qs))
+
         return self
 
     class Meta:
